summary refs log tree commit diff
path: root/guix/build-system/python.scm
diff options
context:
space:
mode:
Diffstat (limited to 'guix/build-system/python.scm')
-rw-r--r--guix/build-system/python.scm3
1 files changed, 2 insertions, 1 deletions
diff --git a/guix/build-system/python.scm b/guix/build-system/python.scm
index e28573bb05..3cd537c752 100644
--- a/guix/build-system/python.scm
+++ b/guix/build-system/python.scm
@@ -93,7 +93,7 @@ prepended to the name."
   (cut package-with-explicit-python <> (default-python2) "python-" "python2-"))
 
 (define* (lower name
                 #:key source inputs native-inputs outputs target
                 (python (default-python))
                 #:allow-other-keys
                 #:rest arguments)
@@ -104,6 +104,7 @@ prepended to the name."
   (and (not target)                               ;XXX: no cross-compilation
        (bag
          (name name)
+         (system system)
          (host-inputs `(,@(if source
                               `(("source" ,source))
                               '())
@@ -93,7 +93,7 @@ prepended to the name."
 
 (define* (lower name
-                #:key source inputs native-inputs outputs target
+                #:key source inputs native-inputs outputs system target
                 (python (default-python))
                 #:allow-other-keys